@@ -7,7 +7,7 @@
 #define _DKIM_TYPES_H_
 
 #ifndef lint
-static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.89 2008/06/05 15:18:19 msk Exp $";
+static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.90 2008/07/10 17:28:37 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -290,7 +290,7 @@ struct dkim_lib
 				                     size_t buflen);
 	DKIM_CBSTAT		(*dkiml_policy_lookup) (DKIM *dkim,
 				                        u_char *query,
-				                        bool usemx,
+				                        bool excheck,
 				                        u_char *buf,
 				                        size_t buflen,
 				                        int *qstat);
