@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char dkim_util_c_id[] = "@(#)$Id: dkim-util.c,v 1.22 2008/05/08 18:59:25 msk Exp $";
+static char dkim_util_c_id[] = "@(#)$Id: dkim-util.c,v 1.23 2008/07/22 20:42:38 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -17,6 +17,9 @@ static char dkim_util_c_id[] = "@(#)$Id: dkim-util.c,v 1.22 2008/05/08 18:59:25
 #include <errno.h>
 
 /* libsm includes */
+#include <sm/gen.h>
+#include <sm/types.h>
+#include <sm/cdefs.h>
 #include <sm/string.h>
 
 /* libdkim includes */
