@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test41_c_id[] = "@(#)$Id: t-test41.c,v 1.11 2007/07/27 05:39:47 msk Exp $";
+static char t_test41_c_id[] = "@(#)$Id: t-test41.c,v 1.12 2008/07/22 20:51:17 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -14,6 +14,9 @@ static char t_test41_c_id[] = "@(#)$Id: t-test41.c,v 1.11 2007/07/27 05:39:47 ms
 #include <stdlib.h>
 #include <stdio.h>
 
+/* libsm includes */
+#include <sm/gen.h>
+
 /* libdkim includes */
 #include "dkim.h"
 #include "t-testdata.h"
